# systemd options
%global _has_systemd %(rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  # this is usually either `common.service' or `%{_has_systemd}.service'
  %global _servicefile_postfix common.service
  %global _targetfile_postfix common.target
%else
  %global _servicefile_postfix init
%endif

Summary: A bridge between a TCP/IP network and a device such as a serial port
Name: remserial
Version: 1.4
Release: 11%{?dist}
License: GPL-2.0-or-later
Group: Applications/System
URL: http://lpccomp.bc.ca/remserial/
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
Source0: http://lpccomp.bc.ca/remserial/%{name}-%{version}.tar.gz
%if %{_has_systemd}
Source1: %{name}@.%{_servicefile_postfix}
Source100: %{name}.%{_targetfile_postfix}
%else
Source1: %{name}.%{_servicefile_postfix}
%endif
Source2: %{name}.sysconfig
Source3: %{name}.conf.sample
Source4: %{name}-execpriv.defaults
Source5: %{name}.README
Patch0: remserial-1.4-misc.patch
BuildRequires: readline-devel, openssl-devel
BuildRoot: %{_tmppath}/%{name}-%{version}-root
Requires: exec-tools >= 0.9
%if %{_has_systemd}
BuildRequires: systemd
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif

%description
The remserial program acts as a communications bridge between a TCP/IP
network port and a Linux device such as a serial port. Any
character-oriented Linux /dev device will work. The program can operate
as a server accepting network connections from other machines,
or as a client, connecting to remote machine that is running the remserial
program or some other program that accepts a raw network connection.

%prep
%setup -q
%patch0 -p1 -b .misc

%build
%{__make} CFLAGS="%{optflags}"

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__install} -d %{buildroot}%{_sysconfdir}/sysconfig
%{__install} -d %{buildroot}%{_sysconfdir}/%{name}.d
%{__install} -d %{buildroot}%{_bindir}

%if %{_has_systemd}
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -d %{buildroot}%{_unitdir}-generators
%{__install} -m 0644 -p %{SOURCE1} %{buildroot}%{_unitdir}/%{name}@.service
%{__install} -m 0644 -p %{SOURCE100} %{buildroot}%{_unitdir}/%{name}.target
%{__ln_s} -f execpriv-generator %{buildroot}%{_unitdir}-generators/%{name}-generator
%else
%{__install} -d %{buildroot}%{_initrddir}
%{__install} -m 0755 -p %{SOURCE1} %{buildroot}%{_initrddir}/%{name}
%endif

%{__install} -m 0644 -p %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{__install} -m 0644 -p %{SOURCE3} %{buildroot}%{_sysconfdir}/%{name}.d/
%{__install} -m 0644 -p %{SOURCE4} %{buildroot}%{_sysconfdir}/%{name}.d/execpriv.defaults
%{__install} -m 0644 -p %{SOURCE5} %{buildroot}%{_sysconfdir}/%{name}.d/README
%{__install} -m 0755 -p %{name} %{buildroot}%{_bindir}/

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%post
%if %{_has_systemd}
%systemd_post %{name}.target
%else
/sbin/chkconfig --add %{name}
%endif

%preun
%if %{_has_systemd}
%systemd_preun %{name}.target
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name} stop > /dev/null 2>&1
  /sbin/chkconfig --del %{name}
fi
%endif

%postun
%if %{_has_systemd}
%systemd_postun_with_restart %{name}.target
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc README.txt
%{_bindir}/%{name}
%if %{_has_systemd}
%{_unitdir}/%{name}@.service
%{_unitdir}/%{name}.target
%{_unitdir}-generators/%{name}-generator
%else
%config %{_initrddir}/%{name}
%endif
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%dir %{_sysconfdir}/%{name}.d
%config(noreplace) %{_sysconfdir}/%{name}.d/%{name}.conf.sample
%config(noreplace) %{_sysconfdir}/%{name}.d/execpriv.defaults
%{_sysconfdir}/%{name}.d/README

%changelog
* Wed Jun 21 2023 Simon Matter <simon.matter@invoca.ch> 1.4-11
- change to *.common.service systemd files
- remove eval where possible
- change to SPDX license tag

* Wed Apr 22 2020 Simon Matter <simon.matter@invoca.ch> 1.4-10
- add support for EL8

* Wed Nov 21 2018 Simon Matter <simon.matter@invoca.ch> 1.4-9
- update for compatibility with exec-tools >= 0.9

* Tue Nov 20 2018 Simon Matter <simon.matter@invoca.ch> 1.4-7
- update for compatibility with exec-tools >= 0.8

* Fri Nov 16 2018 Simon Matter <simon.matter@invoca.ch> 1.4-6
- update for compatibility with exec-tools >= 0.5

* Tue Jun 09 2015 Simon Matter <simon.matter@invoca.ch> 1.4-5
- small fixes for systemd

* Tue Apr 14 2015 Simon Matter <simon.matter@invoca.ch> 1.4-4
- add support for systemd

* Tue May 14 2013 Simon Matter <simon.matter@invoca.ch> 1.4-3
- cosmetic changes to init script

* Wed Sep 07 2011 Simon Matter <simon.matter@invoca.ch> 1.4-2
- fix some compile warnings

* Wed Sep 07 2011 Simon Matter <simon.matter@invoca.ch> 1.4-1
- initial package
